;; Generated package description from eglot.el  -*- no-byte-compile: t -*-
(define-package "eglot" "1.21" "The Emacs Client for LSP servers" '((emacs "26.3") (eldoc "1.14.0") (external-completion "0.1") (flymake "1.4.2") (jsonrpc "1.0.26") (project "0.11.2") (seq "2.23") (xref "1.6.2")) :commit "12730179acddc224f0c43a2b8e8a028182d1e40f" :authors '(("João Távora" . "joaotavora@gmail.com")) :maintainer '("João Távora" . "joaotavora@gmail.com") :keywords '("convenience" "languages") :url "https://github.com/joaotavora/eglot")
